import { cloneElement } from 'react';
import PropTypes from 'prop-types';
import { ATOM_ICON_DISPLAY_NAME, ATOM_ICON_SIZES_MAPPER, CLASS, ICON_POSITIONS, SIZES } from './config';
/**
 * Detect if element is an AtomIcon to force correct size
 * @param {React.ReactElement} icon
 */

import { jsx as _jsx } from "react/jsx-runtime";

var isAtomIcon = function isAtomIcon(icon) {
  var _icon$type;

  return (icon == null ? void 0 : (_icon$type = icon.type) == null ? void 0 : _icon$type.displayName) === ATOM_ICON_DISPLAY_NAME;
};
/**
 * Prepare the AtomIcon element to use the correct size
 * @param {React.ReactElement} atomIconElement
 * @param {object} options
 * @param {string} options.size Size of the button to grab the correct icon size
 */


var prepareAtomIcon = function prepareAtomIcon(atomIconElement, _ref) {
  var size = _ref.size;
  var atomIconSize = ATOM_ICON_SIZES_MAPPER[size];
  return /*#__PURE__*/cloneElement(atomIconElement, {
    color: undefined,
    size: atomIconSize
  });
};

export default function ButtonIcon(_ref2) {
  var children = _ref2.children,
      position = _ref2.position,
      size = _ref2.size;
  if (!children) return null; // if the icon is an AtomIcon we've to be sure correct props are used

  var iconToRender = isAtomIcon(children) ? prepareAtomIcon(children, {
    size: size
  }) : children;
  return /*#__PURE__*/_jsx("span", {
    className: CLASS + "-" + position + "Icon",
    children: iconToRender
  });
}